@@ -1,7 +1,7 @@
-"""AMQP Messaging Framework for Python"""
+"""Messaging Framework for Python"""
 from __future__ import absolute_import
 
-VERSION = (2, 1, 2)
+VERSION = (2, 1, 3)
 __version__ = ".".join(map(str, VERSION[0:3])) + "".join(VERSION[3:])
 __author__ = "Ask Solem"
 __contact__ = "ask@celeryproject.org"
